ReasonedEvidence
================

.. currentmodule:: semra.struct

.. autoclass:: ReasonedEvidence
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ReasonedEvidence.explanation
      ~ReasonedEvidence.mapping_set
      ~ReasonedEvidence.mapping_set_names
      ~ReasonedEvidence.model_computed_fields
      ~ReasonedEvidence.model_config
      ~ReasonedEvidence.model_fields

   .. rubric:: Methods Summary

   .. autosummary::

      ~ReasonedEvidence.get_confidence
      ~ReasonedEvidence.key

   .. rubric:: Attributes Documentation

   .. autoattribute:: explanation
   .. autoattribute:: mapping_set
   .. autoattribute:: mapping_set_names
   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields

   .. rubric:: Methods Documentation

   .. automethod:: get_confidence
   .. automethod:: key
